@@ -2,6 +2,9 @@ from __future__ import annotations
 
 import pytest
 
+from dask._task_spec import Alias
+from dask.base import collections_to_dsk
+
 pytest.importorskip("numpy")
 
 import numpy as np
@@ -513,6 +516,34 @@ def test_diag_extraction(k):
     assert_eq(da.diag(d, k), np.diag(y, k))
 
 
+def test_creation_data_producers():
+    x = np.arange(64).reshape((8, 8))
+    d = da.from_array(x, chunks=(4, 4))
+    dsk = collections_to_dsk([d])
+    assert all(v.data_producer for v in dsk.values())
+
+    # blockwise fusion
+    x = d.astype("float64")
+    dsk = collections_to_dsk([x])
+    assert sum(v.data_producer for v in dsk.values()) == 4
+    assert sum(isinstance(v, Alias) for v in dsk.values()) == 4
+    assert len(dsk) == 8
+
+    # linear fusion
+    x = d[slice(0, 6), None].astype("float64")
+    dsk = collections_to_dsk([x])
+    assert sum(v.data_producer for v in dsk.values()) == 4
+    assert sum(isinstance(v, Alias) for v in dsk.values()) == 4
+    assert len(dsk) == 8
+
+    # no fusion
+    x = d[[1, 3, 5, 7, 6, 4, 2, 0]].astype("float64")
+    dsk = collections_to_dsk([x])
+    assert sum(v.data_producer and "array-" in k[0] for k, v in dsk.items()) == 4
+    assert sum(v.data_producer for v in dsk.values()) == 8  # getitem data nodes
+    assert len(dsk) == 24
+
+
 def test_diagonal():
     v = np.arange(11)
     with pytest.raises(ValueError):
@@ -957,6 +988,22 @@ def test_nan_zeros_ones_like(fn, shape_chunks, dtype):
     )
 
 
+def test_from_array_getitem_fused():
+    arr = np.arange(100).reshape(10, 10)
+    darr = da.from_array(arr, chunks=(5, 5))
+    result = darr[slice(1, 5), :][slice(1, 3), :]
+    dsk = collections_to_dsk([result])
+    # Ensure that slices are merged properly
+    key = [k for k in dsk if "array-getitem" in k[0]][0]
+    key_2 = [
+        k
+        for k, v in dsk[key].args[0].items()
+        if "getitem" in k[0] and not isinstance(v, Alias)
+    ][0]
+    assert dsk[key].args[0][key_2].args[1] == ((slice(2, 4), slice(0, None)))
+    assert_eq(result, arr[slice(1, 5), :][slice(1, 3), :])
+
+
 @pytest.mark.parametrize("shape_chunks", [((50, 4), (10, 2)), ((50,), (10,))])
 @pytest.mark.parametrize("dtype", ["u4", np.float32, None, np.int64])
 def test_nan_empty_like(shape_chunks, dtype):
