@@ -2,16 +2,18 @@ from __future__ import annotations
 
 import re
 import string
+import warnings
+from collections.abc import Callable
 from dataclasses import asdict, dataclass, field
-from typing import Any, Callable, cast
+from typing import Any, cast
 
 import numpy as np
 import pandas as pd
 
+from dask.dataframe._compat import PANDAS_GE_220, PANDAS_GE_300
 from dask.dataframe._pyarrow import is_object_string_dtype
-from dask.dataframe.core import tokenize
-from dask.dataframe.io.io import from_map
 from dask.dataframe.io.utils import DataFrameIOFunction
+from dask.tokenize import tokenize
 from dask.utils import random_state_data
 
 __all__ = [
@@ -287,8 +289,6 @@ class MakeDataframePart(DataFrameIOFunction):
 
     def __call__(self, part):
         divisions, state_data = part
-        if isinstance(state_data, int):
-            state_data = random_state_data(1, state_data)
         return make_dataframe_part(
             self.index_dtype,
             divisions[0],
@@ -349,16 +349,20 @@ def make_partition(columns: list, dtypes: dict[str, type | str], index, kwargs,
         if k in columns and not same_astype(v, df[k].dtype)
     }
     if update_dtypes:
-        df = df.astype(update_dtypes, copy=False)
+        kwargs = {} if PANDAS_GE_300 else {"copy": False}
+        df = df.astype(update_dtypes, **kwargs)
     return df
 
 
+_ME = "ME" if PANDAS_GE_220 else "M"
+
+
 def make_timeseries(
     start="2000-01-01",
     end="2000-12-31",
     dtypes=None,
     freq="10s",
-    partition_freq="1M",
+    partition_freq=f"1{_ME}",
     seed=None,
     **kwargs,
 ):
@@ -388,7 +392,7 @@ def make_timeseries(
     >>> import dask.dataframe as dd
     >>> df = dd.demo.make_timeseries('2000', '2010',
     ...                              {'value': float, 'name': str, 'id': int},
-    ...                              freq='2H', partition_freq='1D', seed=1)
+    ...                              freq='2h', partition_freq='1D', seed=1)
     >>> df.head()  # doctest: +SKIP
                            id      name     value
     2000-01-01 00:00:00   969     Jerry -0.309014
@@ -418,24 +422,39 @@ def make_timeseries(
     index_dtype = "datetime64[ns]"
     meta_start, meta_end = list(pd.date_range(start="2000", freq=freq, periods=2))
 
+    from dask.dataframe import _dask_expr_enabled
+
+    if _dask_expr_enabled():
+        from dask.dataframe.dask_expr import from_map
+
+        k = {}
+    else:
+        from dask.dataframe.io.io import from_map
+
+        k = {"token": tokenize(start, end, dtypes, freq, partition_freq, state_data)}
+
     # Construct the output collection with from_map
-    return from_map(
-        MakeDataframePart(index_dtype, dtypes, kwargs),
-        parts,
-        meta=make_dataframe_part(
-            index_dtype,
-            meta_start,
-            meta_end,
-            dtypes,
-            list(dtypes.keys()),
-            state_data[0],
-            kwargs,
-        ),
-        divisions=divisions,
-        label="make-timeseries",
-        token=tokenize(start, end, dtypes, freq, partition_freq, state_data),
-        enforce_metadata=False,
-    )
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message="dask_expr does not", category=UserWarning
+        )
+        return from_map(
+            MakeDataframePart(index_dtype, dtypes, kwargs),
+            parts,
+            meta=make_dataframe_part(
+                index_dtype,
+                meta_start,
+                meta_end,
+                dtypes,
+                list(dtypes.keys()),
+                state_data[0],
+                kwargs,
+            ),
+            divisions=divisions,
+            label="make-timeseries",
+            enforce_metadata=False,
+            **k,
+        )
 
 
 def with_spec(spec: DatasetSpec, seed: int | None = None):
@@ -547,20 +566,28 @@ def with_spec(spec: DatasetSpec, seed: int | None = None):
 
     parts = [(divisions[i : i + 2], state_data[i]) for i in range(npartitions)]
 
-    return from_map(
-        MakeDataframePart(spec.index_spec.dtype, dtypes, kwargs, columns=columns),
-        parts,
-        meta=make_dataframe_part(
-            spec.index_spec.dtype,
-            meta_start,
-            meta_end,
-            dtypes,
-            columns,
-            state_data[0],
-            kwargs,
-        ),
-        divisions=divisions,
-        label="make-random",
-        token=tokenize(0, spec.nrecords, dtypes, step, partition_freq, state_data),
-        enforce_metadata=False,
-    )
+    from dask.dataframe import from_map
+
+    k = {}  # type: ignore
+
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message="dask_expr does not", category=UserWarning
+        )
+        return from_map(
+            MakeDataframePart(spec.index_spec.dtype, dtypes, kwargs, columns=columns),
+            parts,
+            meta=make_dataframe_part(
+                spec.index_spec.dtype,
+                meta_start,
+                meta_end,
+                dtypes,
+                columns,
+                state_data[0],
+                kwargs,
+            ),
+            divisions=divisions,
+            label="make-random",
+            enforce_metadata=False,
+            **k,
+        )
