@@ -27,23 +27,11 @@ from dask.dataframe.utils import (
     meta_series_constructor,
     pyarrow_strings_enabled,
     raise_on_meta_error,
-    shard_df_on_index,
     valid_divisions,
 )
 from dask.local import get_sync
 
 
-def test_shard_df_on_index():
-    df = pd.DataFrame(
-        {"x": [1, 2, 3, 4, 5, 6], "y": list("abdabd")}, index=[10, 20, 30, 40, 50, 60]
-    )
-
-    result = list(shard_df_on_index(df, [20, 50]))
-    assert list(result[0].index) == [10]
-    assert list(result[1].index) == [20, 30, 40]
-    assert list(result[2].index) == [50, 60]
-
-
 def test_make_meta():
     df = pd.DataFrame(
         {"a": [1, 2, 3], "b": list("abc"), "c": [1.0, 2.0, 3.0]}, index=[10, 20, 30]
@@ -410,10 +398,11 @@ def test_check_meta():
     # Series metadata error
     with pytest.raises(ValueError) as err:
         check_meta(d, meta.d.astype("f8"), numeric_equal=False)
+    series = "pandas.core.series.Series" if not PANDAS_GE_300 else "pandas.Series"
     assert str(err.value) == (
         "Metadata mismatch found.\n"
         "\n"
-        "Partition type: `pandas.core.series.Series`\n"
+        f"Partition type: `{series}`\n"
         "+----------+---------+\n"
         "|          | dtype   |\n"
         "+----------+---------+\n"
@@ -449,7 +438,7 @@ def test_check_meta():
     assert str(err.value) == (
         "Metadata mismatch found.\n"
         "\n"
-        "Partition type: `pandas.core.series.Series`\n"
+        f"Partition type: `{series}`\n"
         "+----------+--------+\n"
         "|          | dtype  |\n"
         "+----------+--------+\n"
@@ -463,7 +452,12 @@ def test_check_matching_columns_raises_appropriate_errors():
     df = pd.DataFrame(columns=["a", "b", "c"])
 
     meta = pd.DataFrame(columns=["b", "a", "c"])
-    with pytest.raises(ValueError, match="Order of columns does not match"):
+    with pytest.raises(
+        ValueError,
+        match="Order of columns does not match."
+        "\nActual:   \\['a', 'b', 'c'\\]"
+        "\nExpected: \\['b', 'a', 'c'\\]",
+    ):
         assert check_matching_columns(meta, df)
 
     meta = pd.DataFrame(columns=["a", "b", "c", "d"])
